var searchData=
[
  ['v1_20and_20v2_0',['The XKB keymap text format, V1 and V2',['../keymap-text-format-v1-v2.html',1,'']]],
  ['v2_1',['The XKB keymap text format, V1 and V2',['../keymap-text-format-v1-v2.html',1,'']]],
  ['value_2',['XKB-796 – Invalid value',['../error-index.html#XKB-796',1,'']]],
  ['values_3',['values',['../keymap-text-format-v1-v2.html#set-default-values-1',1,'Set default values'],['../keymap-text-format-v1-v2.html#set-default-values-2',1,'Set default values']]],
  ['variables_4',['Environment Variables',['../group__context.html',1,'']]],
  ['variant_5',['variant',['../structxkb__rule__names.html#a758e1865c002d8f4fb59b2e3dda83b66',1,'xkb_rule_names']]],
  ['variants_20and_20symbols_6',['Example: layouts, variants and symbols',['../rule-file-format.html#rules-symbols-example',1,'']]],
  ['virtual_20modifier_7',['XKB-123 – Undeclared virtual modifier',['../error-index.html#XKB-123',1,'']]],
  ['virtual_20modifier_20encoding_8',['How to get the virtual modifier encoding?',['../faq.html#how-to-get-the-virtual-modifier-encoding',1,'']]],
  ['virtual_20modifier_20map_9',['Setting the virtual modifier map',['../keymap-text-format-v1-v2.html#set-virtual-mod-map',1,'']]],
  ['virtual_20modifier_20names_10',['Legacy virtual modifier names',['../group__legacy-virtual-modifier-names.html',1,'']]],
  ['virtual_20modifiers_11',['Virtual modifiers',['../keymap-text-format-v1-v2.html#key-virtual-modifiers',1,'']]],
  ['virtual_20modifiers_12',['Real and virtual modifiers',['../keymap-text-format-v1-v2.html#real-and-virtual-modifiers',1,'']]],
  ['virtual_20modifiers_20names_13',['Virtual modifiers names',['../group__virtual-modifier-names.html',1,'']]],
  ['vs_20kccgst_14',['RMLVO vs KcCGST',['../user-configuration.html#rmlvo-vs-kccgst',1,'']]]
];
